Documentation
¶
Overview ¶
Package negotiate provides a function for HTTP content type negotiation.
Once https://github.com/golang/go/issues/19307 is resolved, this package will no longer be maintained.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ContentType ¶
ContentType returns the best offered content type for the request's Accept header. Offers must include both a MIME type and subtype, e.g. text/plain or image/png. If two offers match with equal weight and specificity, then the offer earlier in the list is preferred. If no offers match, an error is returned.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.